/*
 * ASTRI - Template for Assembly SQL based on ALMA Software Templates
 * (c) INAF/UNIPG, 2021 
 *
 * WARNING! DO NOT MODIFY THIS FILE!
 * 
 *  Generated by: Gino Tosti
 *  Date: 21/06/16
 *  Description: Amc Interface
 *  Filename: AmcBase.py
 *
 */






/* Definiions */

SET @LRUName='Amc';
SET @LRUFullName='Adaptive Mirror Control';
SET @LRUICD='ASTRI';
SET @LRUICDDate=1000000000000;
SET @LRUDescription='Amc Interface';
SET @LRUNotes='';
SET @ASSEMBLY='Amc';
SET @COMPTYPE= 'IDL:astri/tcs/Amc:1.0';
SET @PRODCODE='AmcImpl';
SET @BASELEMENT='Telescope';
SET @MP_Name =' ';
SET @MP_Description=' ';
SET @MP_Format='bb';
SET @MP_DisplayUnits='gg';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
SET @MP_archive_suppress='0';

SELECT 'Transaction BEGIN';


/* LRUType*/

SELECT '1: find out wether LRUType Assembly has already been inserted.';



drop procedure if exists lru;
DELIMITER ;;
create procedure lru() begin
	SELECT COUNT(lruName) INTO @lruNameCount FROM lruType WHERE lruName=@LRUName;
	IF (@lruNameCount > 0) THEN
	  SELECT 'LRU already exists', @LRUName;
	ELSE 
	  SELECT 'No LRU',@LRUName, 'Inserting LRU';
	  INSERT INTO LRUType VALUES (@LRUName, @LRUFullName,@LRUICD,@LRUICDDate,@LRUDescription,@LRUNotes);
	END IF;
end ;;

DELIMITER ;
call lru;
drop procedure lru;
-- SELECT * FROM lruType;

/* ComponentType */
SELECT '2: find out wether ComponentType has already been inserted.';
drop procedure if exists comptype;
DELIMITER ;;
create procedure comptype() begin
	SELECT COUNT(componentTypeId) INTO @componentTypeIdCount FROM componentType WHERE idl= @COMPTYPE;
	IF (@componentTypeIdCount > 0) THEN
	  SELECT 'COMPType already exists', @COMPTYPE;
	ELSE 
	  SELECT 'No COMPType',@COMPTYPE, 'Inserting COMPType';
	  INSERT INTO ComponentType (idl) VALUES (@COMPTYPE);
	END IF;
end ;;

DELIMITER ;
call comptype;
drop procedure comptype;

/* Assembly Type */
SELECT '3: find out wether AssemblyType has already been inserted.';
SELECT componenttypeid INTO @compTypeId FROM componentType WHERE idl=@COMPTYPE;
drop procedure if exists assemblytype;
DELIMITER ;;
create procedure assemblytype() begin
	SELECT COUNT(assemblytypename) INTO @assemblyNameCount FROM assemblyType WHERE assemblytypename=@ASSEMBLY;
	IF (@assemblyNameCount > 0) THEN
	  SELECT 'ASSEMBLYType already exists', @ASSEMBLY;
	ELSE 
	  SELECT 'No ASSEMBLYType',@ASSEMBLY, 'Inserting ASSEMBLYType';
	  
	  INSERT INTO AssemblyType (
           	ASSEMBLYTYPENAME,
        	BASEELEMENTTYPE,
        	LRUNAME,
        	FULLNAME,
        	DESCRIPTION,
        	NOTES,
        	COMPONENTTYPEID,
		PRODUCTIONCODE,
		SIMULATEDCODE)
	    VALUES (
		@ASSEMBLY, 
		@BASELEMENT,
		@ASSEMBLY, 
		@LRUFullName,
		@LRUDescription, 
		'',
		@compTypeId,
		@PRODCODE,
		''
	    );
	END IF;
end ;;
DELIMITER ;
call assemblytype;
drop procedure assemblytype;


/* DefaultComponent */
SELECT '4: find out wether DefaultComponent has already been inserted.';
SELECT defaultcomponentid INTO @defCompId FROM defaultcomponent WHERE assemblytypename=@ASSEMBLY;
drop procedure if exists defcomp;
DELIMITER ;;
create procedure defcomp() begin
   	DECLARE exit_loop INT DEFAULT 0; 
	DECLARE  defaultbacipropid1 INT DEFAULT 0;
	DECLARE  defaultbacipropertyid1 INT DEFAULT 0;      
   	DECLARE propCur CURSOR FOR SELECT defaultbacipropid from defaultbaciproperty where defaultcomponentid = @defCompId;

        DECLARE CONTINUE HANDLER FOR NOT FOUND SET exit_loop = 1;
	
	OPEN propCur;
	SELECT count(defaultcomponentid) INTO @defaultComponentCount FROM defaultComponent WHERE assemblytypename=@ASSEMBLY;
	IF @defaultComponentCount=0 THEN
	    	SELECT 'Inserting defaultcomponent',@ASSEMBLY;
		SELECT MAX(defaultcomponentid) INTO @defCompId FROM defaultComponent;
		SET @defCompId=COALESCE(@defCompId,0)+1;
	    	INSERT INTO DefaultComponent (
			defaultcomponentid,
			ComponentTypeId,
	    		AssemblyTypeName,      
	    		ImplLang,               
	    		RealTime,                
	    		Code,                    
	    		Path,                  
	    		IsAutostart,             
	    		IsDefault,               
	    		IsStandaloneDefined,     
	    		KeepAliveTime,                
	    		MinLogLevel,             
	    		MinLogLevelLocal,       
	    		XMLDoc                   
		)
		   VALUES (
			@defCompId,
			@compTypeId, 
			@ASSEMBLY, 
			'java', 
			'0',
			'Impl.java',
			'Impl.java',
			'0',
			'0',
			'0',
			'5',
			'4',
			'4',
			''
		    );
	ELSE
       bp_loop: 
	LOOP
   -- read the name from next row into the variables 
     	FETCH  propCur INTO defaultbacipropid1;
	delete from defaultmonitorpoint where defaultbacipropertyid = defaultbacipropid1;
	delete from defaultbaciproperty where defaultbacipropid = defaultbacipropid1;
   -- check if the exit_loop flag has been set by mysql, 
   -- close the cursor and exit the loop if it has.
       IF exit_loop THEN
         CLOSE propCur;
         LEAVE bp_loop;
       END IF;
       END LOOP bp_loop;
       END IF;
end ;;
DELIMITER ;
call defcomp;
drop procedure defcomp;

SELECT '5: Inserting DefaultBaciProperties';
drop procedure if exists defbaci;

SELECT COUNT(propertyname) INTO @defaultBACIPropertyCount FROM defaultbaciProperty WHERE propertyname=@MP_Name AND defaultComponentId=@defCompId;

DELIMITER ;;
create procedure defbaci() begin
                IF @defaultBACIPropertyCount=0 THEN
                    SELECT 'Property not found, it will be added...';
                    SELECT 'Inserting BACI Property', @MP_Name;
                    SELECT MAX(defaultBACIPropId) INTO @defaultBACIPropId FROM defaultbaciProperty;
                    SET @defaultBACIPropId=COALESCE(@defaultBACIPropId,0)+1;
                     INSERT INTO DefaultBACIProperty (
                        DEFAULTBACIPROPID,
                        DEFAULTCOMPONENTID,
                        PROPERTYNAME,
                        DESCRIPTION,
                        `FORMAT`,
                        UNITS,
                        RESOLUTION,
                        ARCHIVE_PRIORITY,
                        ARCHIVE_MIN_INT,
                        ARCHIVE_MAX_INT,
                        DEFAULT_TIMER_TRIG,
                        MIN_TIMER_TRIG,
                        INITIALIZE_DEVIO,
                        MIN_DELTA_TRIG,
                        DEFAULT_VALUE,
                        GRAPH_MIN,
                        GRAPH_MAX,
                        MIN_STEP,
                        ARCHIVE_DELTA,
                        ALARM_HIGH_ON,
                        ALARM_LOW_ON,
                        ALARM_HIGH_OFF,
                        ALARM_LOW_OFF,
                        ALARM_TIMER_TRIG,
                        MIN_VALUE,
                        MAX_VALUE,
                        BITDESCRIPTION,
                        WHENSET,
                        WHENCLEARED,
                        STATESDESCRIPTION,
                        `CONDITION`,
                        ALARM_ON,
                        ALARM_OFF,
                        `DATA`,
                        ALARM_FAULT_FAMILY,
                        ALARM_FAULT_MEMBER,
                        ALARM_LEVEL,
                        ARCHIVE_SUPPRESS,
                        ARCHIVE_MECHANISM) 
                    VALUES (
                        @defaultBACIPropId,
                        @defCompId,
                        @MP_Name,
                        @MP_Description,
                        @MP_Format,
			@MP_DisplayUnits,
			'0',
                        '3',
                        '0',
                        @MP_Interval,
                        '1',
                        '1.',
                        '0.',
                        '0.',
                        '0.',
                         @MP_GraphMin,  
                         @MP_GraphMax, 
                        '0',
                        '0',
                        '0',
                        '0',
                        '0',
                        '0',
                        '0',
                        '-2147483648',
                        '2147483647',
                        '',
                        '',
                        '',
                        '',
                        '',
                        '',
                        '',
                        '',
                        '',
                        '',
                        '0',
                        @MP_archive_suppress,
                        'monitor_collector'
                    );

                ELSE 
                    SELECT 'Default BACI Property',@MP_NAME 'already exists... continue';
                    SELECT defaultBACIPropId INTO @defaultBACIPropId FROM defaultbaciProperty WHERE propertyname=@MP_NAME and defaultComponentId=@defCompId;
                END IF;
		SELECT COUNT(monitorPointName) INTO @monitorPropCount FROM defaultMonitorPoint WHERE defaultbacipropertyId=@defaultBACIPropId;
                IF @monitorPropCount=0 THEN
                    SELECT MAX(defaultMonitorPointId) INTO @defaultMonPointId FROM defaultMonitorPoint;
                    SET @defaultMonPointId=COALESCE(@defaultMonPointId,0)+1; 
                    INSERT INTO DefaultMonitorPoint (
                        DEFAULTMONITORPOINTID,
                        DEFAULTBACIPROPERTYID,
                        MONITORPOINTNAME,
                        INDICE,
                        DATATYPE,
                        RCA,
                        TERELATED,
                        RAWDATATYPE,
                        WORLDDATATYPE,
                        UNITS,
                        SCALE,
                        OFFSET,
                        MINRANGE,
                        MAXRANGE,
                        DESCRIPTION)
                    VALUES(
                        @defaultMonPointId,
                        @defaultBACIPropId,
                        @MP_Name,
                        '0',
                        @MP_DataType,
                        's=2',
                        '0',
                        @MP_DataType,
                        @MP_DataType,
                        @MP_DataUnits,
                        '1',
                        '0',
                        @MP_MinRange, 
                        @MP_MaxRange,
                        @MP_Description
                    );
                ELSE 
                    SELECT 'WARNING: Found other Monitor Points associated with property',@MP_Name, 'Skipping unique monitor point insertion.';
                END IF;
END ;;
DELIMITER ;

SET @MP_Name ='MAXTEMPWARNING_GETVAR';
SET @MP_Description='Value of external temperature, expressed in degrees Celsius.';
SET @MP_Format='na';
SET @MP_DisplayUnits='C';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='M1TEMPWARNING_GETVAR';
SET @MP_Description='Read the actual temperature of the Nanotech boards for M1';
SET @MP_Format='na';
SET @MP_DisplayUnits='C';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='M2TEMPWARNING_GETVAR';
SET @MP_Description='Read the actual temperature of the Nanotech boards for M2';
SET @MP_Format='na';
SET @MP_DisplayUnits='C';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='MAXPOWRCONSUMP_GETVAR';
SET @MP_Description='Read the set power consumption limit for the Nanotech Boards';
SET @MP_Format='na';
SET @MP_DisplayUnits='Amp';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='M1POS_GETVAR';
SET @MP_Description='Retrieves the position of the 18 segments of the primary mirror in the X and Y directions with respect to the nominal position (which is defined during the calibration procedures). First 18 elements of the  are the X position, while the last 18 are the Y positions';
SET @MP_Format='na';
SET @MP_DisplayUnits='mm';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='M2POS_GETVAR';
SET @MP_Description='Retrieves the position of defocus (along the Z axis) and tilt (about the Y and X axes) of the secondary mirror. First two elements of the  are the tilt about the Y and X axes respectively, and third element is the Z position. Positions are defined with respect to the nominal position determined during the calibration procedures.';
SET @MP_Format='na';
SET @MP_DisplayUnits='Degree';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='M1POSABS_GETVAR';
SET @MP_Description='Retrieves the position of each single actuator of M1';
SET @MP_Format='na';
SET @MP_DisplayUnits='mm';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='M2POSABS_GETVAR';
SET @MP_Description='Retrieves the position of each single actuator of M2';
SET @MP_Format='na';
SET @MP_DisplayUnits='mm';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='M1ABSLIMITS_GETVAR';
SET @MP_Description='Retrieves the minimum and maximum movements limits of each single actuator of M1';
SET @MP_Format='na';
SET @MP_DisplayUnits='mm';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='M2ABSLIMITS_GETVAR';
SET @MP_Description='Retrieves the minimum and maximum movements limits of each single actuator of M2';
SET @MP_Format='na';
SET @MP_DisplayUnits='mm';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='M1ACTSTATUS_GETVAR';
SET @MP_Description='Retrieves the status of all the M1 actuators';
SET @MP_Format='na';
SET @MP_DisplayUnits='nan';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='M1ERRORSTS_GETVAR';
SET @MP_Description='Retrieves the error status of all the M1 actuators';
SET @MP_Format='na';
SET @MP_DisplayUnits='nan';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='M2ACTSTATUS_GETVAR';
SET @MP_Description='Retrieves the status of all the M2 actuators';
SET @MP_Format='na';
SET @MP_DisplayUnits='nan';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='M2ERRORSTS_GETVAR';
SET @MP_Description='Retrieves the error status of all the M2 actuators';
SET @MP_Format='na';
SET @MP_DisplayUnits='nan';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='ETHERCATERROR_GETVAR';
SET @MP_Description='The monitor collects any error from the ethercat connection between AMCU Module';
SET @MP_Format='na';
SET @MP_DisplayUnits='nan';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='SWVERSION_GETVAR';
SET @MP_Description='The command retrieve the Sw Version that is running';
SET @MP_Format='na';
SET @MP_DisplayUnits='nan';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='CANOPEN_STATUS_M1_GETVAR';
SET @MP_Description='The command retrieves the status of the Can Open module dedicated to M1';
SET @MP_Format='na';
SET @MP_DisplayUnits='TBD';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='CANOPEN_STATUS_M2_GETVAR';
SET @MP_Description='The command retrieves the status of the Can Open module dedicated to 2';
SET @MP_Format='na';
SET @MP_DisplayUnits='TBD';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='ENDAT_STATUS_GETVAR';
SET @MP_Description='Retrieve status of both En-Dat modules';
SET @MP_Format='na';
SET @MP_DisplayUnits='TBD';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='ENCODERPOS_1_GETVAR';
SET @MP_Description='Retrieve the position of the two Encoders of M2';
SET @MP_Format='na';
SET @MP_DisplayUnits='steps';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='ENCODERPOS_2_GETVAR';
SET @MP_Description='Retrieve the position of the two Encoders of M2';
SET @MP_Format='na';
SET @MP_DisplayUnits='steps';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='ENCODERPOS_3_GETVAR';
SET @MP_Description='Retrieve the position of the two Encoders of M2';
SET @MP_Format='na';
SET @MP_DisplayUnits='steps';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
call defbaci;
SET @MP_Name ='ERROR_NUMBER_GETVAR';
SET @MP_Description='The monitor reports the number of errors that has been occurred';
SET @MP_Format='na';
SET @MP_DisplayUnits='nan';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='ERROR_INFORMATION_GETVAR';
SET @MP_Description='The monitor reports the information about the required error. The format is (code,origin,class,timestamp) .  Class filed 1: Alarm 2: Error 3:Warning . The timestamp is in UTC format. Origin and Code are available in a separate document.';
SET @MP_Format='na';
SET @MP_DisplayUnits='nan';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='ERROR_RECOVERED_GETVAR';
SET @MP_Description='The monitor shows the lists of error that has been occurred and recovered. (1:True,2:False,…). The False status means that the corresponding error has been recovered.';
SET @MP_Format='na';
SET @MP_DisplayUnits='nan';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='ERROR_NUMBER_RECOVERED_GETVAR';
SET @MP_Description='The monitor reports the number of errors that has been recovered';
SET @MP_Format='na';
SET @MP_DisplayUnits='nan';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='ERROR_NUMBER_OUTOFRANGE_GETVAR';
SET @MP_Description='The monitor became TRUE when the size of the error buffe is full.The reset command has to be performed.';
SET @MP_Format='na';
SET @MP_DisplayUnits='nan';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
SET @MP_Name ='COMMAND_ACCEPTED_GETVAR';
SET @MP_Description='As some commands will be accepted only when the AMC is in defined status this variable will be set to true when the last command has been accepted.';
SET @MP_Format='na';
SET @MP_DisplayUnits='nan';
SET @MP_GraphMin=0;  
SET @MP_GraphMax=0;
SET @MP_Interval=1;
SET @MP_archive_suppress='0';
SET @MP_MinRange=0;  
SET @MP_MaxRange=0; 
SET @MP_DataType='string';
SET @MP_DataUnits=@MP_DisplayUnits;
call defbaci;
drop procedure defbaci;
SELECT 'Transaction END';

