"""
 * ASTRI - Template for Hardware device scipt based on ALMA Software Templates
 * (c) INAF/UNIPG, 2021 
 *
 * WARNING! DO NOT MODIFY THIS FILE!
 * 
 *  Generated by: Gino Tosti
 *  Date: 21/06/16
 *  Description: Amc Interface
 *  Filename: AmcBase.py
 *
"""

"""
This package is part of the Telescope Command Language (TCL).
It contains the code used for accessing Amc.
"""

import math
import TCL.HardwareDevice

from TCL.Container import getComponent
from TCL.Container import getDynamicComponent
from TCL.logging import getLogger

class AmcBase(TCL.HardwareDevice.HardwareDevice):

    def __init__(self, telescopeName = None, componentName = None, stickyFlag = False):
        """
        The constructor creates a Amc object or a group of Amc
        objects.

        If the telescopeName is defined then this constructor references
        the component running on that . Alternativly the full
        componentName can be specified if desired.

        If telescopeName or componentName are specified as list then a set of
        Amc components are created.

        The AmcBase class is a python proxy to the Amc
        component. The component can be running before creating this
        proxy but if it is not it will be started. The object reference
        is obtained using a call to getComponent (stickyFlag = True)
        or to getComponentNonSticky (stickyFlag = False, default).

        An exception is thrown if there is a problem creating
        this component, establishing the connection to the
        previously mentioned hardware components, or if either
        both or neither telescopeName and componentName are specified.

        EXAMPLE:
        import TCL.AmcBase
        obj = TCL.AmcBase.AmcBase("ASTRI1")

        or

        import TCL.AmcBase
        obj = TCL.AmcBase.AmcBase(["ASTRI1", "ASTRI2",...])
        """

        self._devices = {}

        if ((isinstance(telescopeName, list) == True) or
            (isinstance(componentName, list) == True)):
            if isinstance(telescopeName, list) == True:
                if len(telescopeName) != 0:
                    for idx in range(0, len(telescopeName)):
                        self._devices["SCADA/" + telescopeName[idx] + "/"+"Amc"] = ""
            if isinstance(componentName, list) == True:
                if len(componentName) != 0:
                    for idx in range(0, len(componentName)):
                        self._devices[componentName[idx]] = ""
        else:
            if((telescopeName == None) and (componentName == None)):
                raise (NameError, "missing telescopeName or componentName")
            elif((telescopeName != None) and (componentName != None)):
                raise (NameError, "missing telescopeName or componentName")

            if telescopeName != None:
                self._devices["SCADA/" + telescopeName + "/"+"Amc"] = ""

            if componentName != None:
                self._devices[componentName] = ""

        for key, val in self._devices.items():
            TCL.HardwareDevice.HardwareDevice.__init__(self, key, stickyFlag)
            self._devices[key] = self._HardwareDevice__hw
        self.__logger = getLogger()

    def __del__(self):
        for key, val in self._devices.items():
            instance = self._devices[key]
            del(instance)
        TCL.HardwareDevice.HardwareDevice.__del__(self)

   
     # --------------------- Monitor Points ---------------------
    
    # MAXTEMPWARNING_GETVAR
    def GET_MAXTEMPWARNING_GETVAR(self):
        """
	Value of external temperature, expressed in degrees Celsius.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_MAXTEMPWARNING_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M1TEMPWARNING_GETVAR
    def GET_M1TEMPWARNING_GETVAR(self):
        """
	Read the actual temperature of the Nanotech boards for M1
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_M1TEMPWARNING_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M2TEMPWARNING_GETVAR
    def GET_M2TEMPWARNING_GETVAR(self):
        """
	Read the actual temperature of the Nanotech boards for M2
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_M2TEMPWARNING_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # MAXPOWRCONSUMP_GETVAR
    def GET_MAXPOWRCONSUMP_GETVAR(self):
        """
	Read the set power consumption limit for the Nanotech Boards
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_MAXPOWRCONSUMP_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M1POS_GETVAR
    def GET_M1POS_GETVAR(self):
        """
	Retrieves the position of the 18 segments of the primary mirror in the X and Y directions with respect to the nominal position (which is defined during the calibration procedures). First 18 elements of the  are the X position, while the last 18 are the Y positions
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_M1POS_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M2POS_GETVAR
    def GET_M2POS_GETVAR(self):
        """
	Retrieves the position of defocus (along the Z axis) and tilt (about the Y and X axes) of the secondary mirror. First two elements of the  are the tilt about the Y and X axes respectively, and third element is the Z position. Positions are defined with respect to the nominal position determined during the calibration procedures.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_M2POS_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M1POSABS_GETVAR
    def GET_M1POSABS_GETVAR(self):
        """
	Retrieves the position of each single actuator of M1
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_M1POSABS_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M2POSABS_GETVAR
    def GET_M2POSABS_GETVAR(self):
        """
	Retrieves the position of each single actuator of M2
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_M2POSABS_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M1ABSLIMITS_GETVAR
    def GET_M1ABSLIMITS_GETVAR(self):
        """
	Retrieves the minimum and maximum movements limits of each single actuator of M1
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_M1ABSLIMITS_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M2ABSLIMITS_GETVAR
    def GET_M2ABSLIMITS_GETVAR(self):
        """
	Retrieves the minimum and maximum movements limits of each single actuator of M2
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_M2ABSLIMITS_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M1ACTSTATUS_GETVAR
    def GET_M1ACTSTATUS_GETVAR(self):
        """
	Retrieves the status of all the M1 actuators
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_M1ACTSTATUS_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M1ERRORSTS_GETVAR
    def GET_M1ERRORSTS_GETVAR(self):
        """
	Retrieves the error status of all the M1 actuators
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_M1ERRORSTS_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M2ACTSTATUS_GETVAR
    def GET_M2ACTSTATUS_GETVAR(self):
        """
	Retrieves the status of all the M2 actuators
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_M2ACTSTATUS_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M2ERRORSTS_GETVAR
    def GET_M2ERRORSTS_GETVAR(self):
        """
	Retrieves the error status of all the M2 actuators
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_M2ERRORSTS_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # ETHERCATERROR_GETVAR
    def GET_ETHERCATERROR_GETVAR(self):
        """
	The monitor collects any error from the ethercat connection between AMCU Module
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_ETHERCATERROR_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # SWVERSION_GETVAR
    def GET_SWVERSION_GETVAR(self):
        """
	The command retrieve the Sw Version that is running
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_SWVERSION_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # CANOPEN_STATUS_M1_GETVAR
    def GET_CANOPEN_STATUS_M1_GETVAR(self):
        """
	The command retrieves the status of the Can Open module dedicated to M1
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_CANOPEN_STATUS_M1_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # CANOPEN_STATUS_M2_GETVAR
    def GET_CANOPEN_STATUS_M2_GETVAR(self):
        """
	The command retrieves the status of the Can Open module dedicated to 2
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_CANOPEN_STATUS_M2_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # ENDAT_STATUS_GETVAR
    def GET_ENDAT_STATUS_GETVAR(self):
        """
	Retrieve status of both En-Dat modules
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_ENDAT_STATUS_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # ENCODERPOS_1_GETVAR
    def GET_ENCODERPOS_1_GETVAR(self):
        """
	Retrieve the position of the two Encoders of M2
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_ENCODERPOS_1_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # ENCODERPOS_2_GETVAR
    def GET_ENCODERPOS_2_GETVAR(self):
        """
	Retrieve the position of the two Encoders of M2
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_ENCODERPOS_2_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # ENCODERPOS_3_GETVAR
    def GET_ENCODERPOS_3_GETVAR(self):
        """
	Retrieve the position of the two Encoders of M2
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_ENCODERPOS_3_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # STATUS_GETVAR
    def GET_STATUS_GETVAR(self):
        """
	Retrieves the status of the AMC system
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_STATUS_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # ERROR_NUMBER_GETVAR
    def GET_ERROR_NUMBER_GETVAR(self):
        """
	The monitor reports the number of errors that has been occurred
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_ERROR_NUMBER_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # ERROR_INFORMATION_GETVAR
    def GET_ERROR_INFORMATION_GETVAR(self):
        """
	The monitor reports the information about the required error. The format is (code,origin,class,timestamp) .  Class filed 1: Alarm 2: Error 3:Warning . The timestamp is in UTC format. Origin and Code are available in a separate document.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_ERROR_INFORMATION_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # ERROR_RECOVERED_GETVAR
    def GET_ERROR_RECOVERED_GETVAR(self):
        """
	The monitor shows the lists of error that has been occurred and recovered. (1:True,2:False,…). The False status means that the corresponding error has been recovered.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_ERROR_RECOVERED_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # ERROR_NUMBER_RECOVERED_GETVAR
    def GET_ERROR_NUMBER_RECOVERED_GETVAR(self):
        """
	The monitor reports the number of errors that has been recovered
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_ERROR_NUMBER_RECOVERED_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # ERROR_NUMBER_OUTOFRANGE_GETVAR
    def GET_ERROR_NUMBER_OUTOFRANGE_GETVAR(self):
        """
	The monitor became TRUE when the size of the error buffe is full.The reset command has to be performed.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_ERROR_NUMBER_OUTOFRANGE_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # COMMAND_ACCEPTED_GETVAR
    def GET_COMMAND_ACCEPTED_GETVAR(self):
        """
	As some commands will be accepted only when the AMC is in defined status this variable will be set to true when the last command has been accepted.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_AMC_COMMAND_ACCEPTED_GETCMD()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result


    
    # --------------------- SET Points ---------------------
    
    # M1DELTA_SETVAR
    def SET_M1DELTA_SETVAR(self, arg):
       
        """
	Defines the requested relative displacement along the X and Y axis (wrt the focal plane) for each of the 18 segments to be applied by the MODE_AMC_MOVEM1 command. First 18 elements of the array are the X displacements, while the last 18 are the Y displacements.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_AMC_M1DELTA_SETCMD(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M2DELTA_SETVAR
    def SET_M2DELTA_SETVAR(self, arg):
       
        """
	Change the WS update time (value = 4)
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_AMC_M2DELTA_SETCMD(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # MAXTEMPWARNING_SETVAR
    def SET_MAXTEMPWARNING_SETVAR(self, arg):
       
        """
	The command set the max allowable temperature threshold set for the Nanotec boards.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_AMC_MAXTEMPWARNING_SETCMD(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M1ABSLIMITS_SETVAR
    def SET_M1ABSLIMITS_SETVAR(self, arg):
       
        """
	Defines the min and max limits of the motors movements. The first 36 elements defines the minimum limits of the M1 motors and the last 36 the maximum limits.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_AMC_M1ABSLIMITS_SETCMD(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M2ABSLIMITS_SETVAR
    def SET_M2ABSLIMITS_SETVAR(self, arg):
       
        """
	Defines the min and max limits of the motors movements. The first 3 elements defines the minimum limits of the M2 motors and the last 3 the maximum limits.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_AMC_M2ABSLIMITS_SETCMD(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M1STEPS_SETVAR
    def SET_M1STEPS_SETVAR(self, arg):
       
        """
	Defines the requested displacement for each of the 36th motors to be applied by MODE_AMC_MOVEM1 command.STEPS.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_AMC_M1STEPS_SETCMD(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # CALDIR_SETVAR
    def SET_CALDIR_SETVAR(self, arg):
       
        """
	Set the directory containing the calibration coefficients defined by the parameter. In order to load the coefficients use CMD.AMC_LOADCONF command
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_AMC_CALDIR_SETCMD(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M1ABSPOS_SETVAR
    def SET_M1ABSPOS_SETVAR(self, arg):
       
        """
	Used to move one single actuator of the primary mirror. To be used only to recover from an error.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_AMC_M1ABSPOS_SETCMD(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # M2ABSPOS_SETVAR
    def SET_M2ABSPOS_SETVAR(self, arg):
       
        """
	Used to move one single actuator of the secondary mirror. To be used only to recover from an error.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_AMC_M2ABSPOS_SETCMD(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # ERROR_INFO_SETVAR
    def SET_ERROR_INFO_SETVAR(self, arg):
       
        """
	This command enables access to the information about the required error.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_AMC_ERROR_INFO_SETCMD(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result


    # ----------------- List of Monitor Points ------------------
    def getMonitorList(self):
        """
        This method returns a list containing all monitor point
        names of this hardware device.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            monitorList = []
            monitorList.append("MAXTEMPWARNING_GETVAR --> xx.GET_MAXTEMPWARNING_GETVAR()")
            monitorList.append("M1TEMPWARNING_GETVAR --> xx.GET_M1TEMPWARNING_GETVAR()")
            monitorList.append("M2TEMPWARNING_GETVAR --> xx.GET_M2TEMPWARNING_GETVAR()")
            monitorList.append("MAXPOWRCONSUMP_GETVAR --> xx.GET_MAXPOWRCONSUMP_GETVAR()")
            monitorList.append("M1POS_GETVAR --> xx.GET_M1POS_GETVAR()")
            monitorList.append("M2POS_GETVAR --> xx.GET_M2POS_GETVAR()")
            monitorList.append("M1POSABS_GETVAR --> xx.GET_M1POSABS_GETVAR()")
            monitorList.append("M2POSABS_GETVAR --> xx.GET_M2POSABS_GETVAR()")
            monitorList.append("M1ABSLIMITS_GETVAR --> xx.GET_M1ABSLIMITS_GETVAR()")
            monitorList.append("M2ABSLIMITS_GETVAR --> xx.GET_M2ABSLIMITS_GETVAR()")
            monitorList.append("M1ACTSTATUS_GETVAR --> xx.GET_M1ACTSTATUS_GETVAR()")
            monitorList.append("M1ERRORSTS_GETVAR --> xx.GET_M1ERRORSTS_GETVAR()")
            monitorList.append("M2ACTSTATUS_GETVAR --> xx.GET_M2ACTSTATUS_GETVAR()")
            monitorList.append("M2ERRORSTS_GETVAR --> xx.GET_M2ERRORSTS_GETVAR()")
            monitorList.append("ETHERCATERROR_GETVAR --> xx.GET_ETHERCATERROR_GETVAR()")
            monitorList.append("SWVERSION_GETVAR --> xx.GET_SWVERSION_GETVAR()")
            monitorList.append("CANOPEN_STATUS_M1_GETVAR --> xx.GET_CANOPEN_STATUS_M1_GETVAR()")
            monitorList.append("CANOPEN_STATUS_M2_GETVAR --> xx.GET_CANOPEN_STATUS_M2_GETVAR()")
            monitorList.append("ENDAT_STATUS_GETVAR --> xx.GET_ENDAT_STATUS_GETVAR()")
            monitorList.append("ENCODERPOS_1_GETVAR --> xx.GET_ENCODERPOS_1_GETVAR()")
            monitorList.append("ENCODERPOS_2_GETVAR --> xx.GET_ENCODERPOS_2_GETVAR()")
            monitorList.append("ENCODERPOS_3_GETVAR --> xx.GET_ENCODERPOS_3_GETVAR()")
            monitorList.append("STATUS_GETVAR --> xx.GET_STATUS_GETVAR()")
            monitorList.append("ERROR_NUMBER_GETVAR --> xx.GET_ERROR_NUMBER_GETVAR()")
            monitorList.append("ERROR_INFORMATION_GETVAR --> xx.GET_ERROR_INFORMATION_GETVAR()")
            monitorList.append("ERROR_RECOVERED_GETVAR --> xx.GET_ERROR_RECOVERED_GETVAR()")
            monitorList.append("ERROR_NUMBER_RECOVERED_GETVAR --> xx.GET_ERROR_NUMBER_RECOVERED_GETVAR()")
            monitorList.append("ERROR_NUMBER_OUTOFRANGE_GETVAR --> xx.GET_ERROR_NUMBER_OUTOFRANGE_GETVAR()")
            monitorList.append("COMMAND_ACCEPTED_GETVAR --> xx.GET_COMMAND_ACCEPTED_GETVAR()")
            result[telName] = monitorList
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # ----------------- List of SET Points ------------------
    def getSetList(self):
        """
        This method returns a list containing all set point
        names of this hardware device.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            setList = []
            setList.append("M1DELTA_SETVAR --> xx.SET_M1DELTA_SETVAR(val)")
            setList.append("M2DELTA_SETVAR --> xx.SET_M2DELTA_SETVAR(val)")
            setList.append("MAXTEMPWARNING_SETVAR --> xx.SET_MAXTEMPWARNING_SETVAR(val)")
            setList.append("M1ABSLIMITS_SETVAR --> xx.SET_M1ABSLIMITS_SETVAR(val)")
            setList.append("M2ABSLIMITS_SETVAR --> xx.SET_M2ABSLIMITS_SETVAR(val)")
            setList.append("M1STEPS_SETVAR --> xx.SET_M1STEPS_SETVAR(val)")
            setList.append("CALDIR_SETVAR --> xx.SET_CALDIR_SETVAR(val)")
            setList.append("M1ABSPOS_SETVAR --> xx.SET_M1ABSPOS_SETVAR(val)")
            setList.append("M2ABSPOS_SETVAR --> xx.SET_M2ABSPOS_SETVAR(val)")
            setList.append("ERROR_INFO_SETVAR --> xx.SET_ERROR_INFO_SETVAR(val)")
            result[telName] = setList
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result



