"""
 * ASTRI - Template for Hardware device scipt based on ALMA Software Templates
 * (c) INAF/UNIPG, 2021 
 *
 * WARNING! DO NOT MODIFY THIS FILE!
 * 
 *  Generated by: Gino Tosti
 *  Date: 21/06/16
 *  Description: test device Interface
 *  Filename: testDeviceBase.py
 *
"""

"""
This package is part of the Telescope Command Language (TCL).
It contains the code used for accessing testDevice.
"""

import math
import TCL.HardwareDevice

from TCL.Container import getComponent
from TCL.Container import getDynamicComponent
from TCL.logging import getLogger

class testDeviceBase(TCL.HardwareDevice.HardwareDevice):

    def __init__(self, telescopeName = None, componentName = None, stickyFlag = False):
        """
        The constructor creates a testDevice object or a group of testDevice
        objects.

        If the telescopeName is defined then this constructor references
        the component running on that . Alternativly the full
        componentName can be specified if desired.

        If telescopeName or componentName are specified as list then a set of
        testDevice components are created.

        The testDeviceBase class is a python proxy to the testDevice
        component. The component can be running before creating this
        proxy but if it is not it will be started. The object reference
        is obtained using a call to getComponent (stickyFlag = True)
        or to getComponentNonSticky (stickyFlag = False, default).

        An exception is thrown if there is a problem creating
        this component, establishing the connection to the
        previously mentioned hardware components, or if either
        both or neither telescopeName and componentName are specified.

        EXAMPLE:
        import TCL.testDeviceBase
        obj = TCL.testDeviceBase.testDeviceBase("ASTRI1")

        or

        import TCL.testDeviceBase
        obj = TCL.testDeviceBase.testDeviceBase(["ASTRI1", "ASTRI2",...])
        """

        self._devices = {}

        if ((isinstance(telescopeName, list) == True) or
            (isinstance(componentName, list) == True)):
            if isinstance(telescopeName, list) == True:
                if len(telescopeName) != 0:
                    for idx in range(0, len(telescopeName)):
                        self._devices["SCADA/" + telescopeName[idx] + "/"+"testDevice"] = ""
            if isinstance(componentName, list) == True:
                if len(componentName) != 0:
                    for idx in range(0, len(componentName)):
                        self._devices[componentName[idx]] = ""
        else:
            if((telescopeName == None) and (componentName == None)):
                raise (NameError, "missing telescopeName or componentName")
            elif((telescopeName != None) and (componentName != None)):
                raise (NameError, "missing telescopeName or componentName")

            if telescopeName != None:
                self._devices["SCADA/" + telescopeName + "/"+"testDevice"] = ""

            if componentName != None:
                self._devices[componentName] = ""

        for key, val in self._devices.items():
            TCL.HardwareDevice.HardwareDevice.__init__(self, key, stickyFlag)
            self._devices[key] = self._HardwareDevice__hw
        self.__logger = getLogger()

    def __del__(self):
        for key, val in self._devices.items():
            instance = self._devices[key]
            del(instance)
        TCL.HardwareDevice.HardwareDevice.__del__(self)

   
     # --------------------- Monitor Points ---------------------
    
    # AZACTPOS
    def GET_AZACTPOS(self):
        """
	The Monitor shows the current position of the AZ axis in Sky Coordinate System (zero point at North). The offset is included.Tpoint and Refraction contributions are not take into account.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_TCU_AZACTPOS()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # AZENCPOS
    def GET_AZENCPOS(self):
        """
	The monitor shows the encoder position of the AZ axis without the offset (Encoder Coordinate  System).
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_TCU_AZENCPOS()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # AZTELPOS
    def GET_AZTELPOS(self):
        """
	The Monitor shows the current position of the AZ axis in Telescope Coordinate System (zero point at East). The offset is included.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_TCU_AZTELPOS()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # AZACTVEL
    def GET_AZACTVEL(self):
        """
	The monitor shows the current velocity of the AZ axis
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_TCU_AZACTVEL()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # AZACTACC
    def GET_AZACTACC(self):
        """
	The monitor shows the current acceleration of the AZ axis
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_TCU_AZACTACC()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # AZTPOINT_CORR
    def GET_AZTPOINT_CORR(self):
        """
	This monitor shows the tpoint correction factor for the AZ axis applied at the target trajectory during tracking
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_TCU_AZTPOINT_CORR()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # ELTPOINT_CORR
    def GET_ELTPOINT_CORR(self):
        """
	This monitor shows the tpoint correction factor for the EL axis applied at the target trajectory during tracking
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_TCU_ELTPOINT_CORR()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # REFRACTION_CORR
    def GET_REFRACTION_CORR(self):
        """
	This monitor shows the refraction correction factor for the EL axis applied at the target trajectory during tracking
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].GET_TCU_REFRACTION_CORR()
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result


    
    # --------------------- SET Points ---------------------
    
    # AZMAXACC
    def SET_AZMAXACC(self, arg):
       
        """
	The command sets the max allowable acceleration of the Az axis
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_TCU_AZMAXACC(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # AZMAXDEC
    def SET_AZMAXDEC(self, arg):
       
        """
	The command sets the max allowable deceleration of the Az axis
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_TCU_AZMAXDEC(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # AZMAXVEL
    def SET_AZMAXVEL(self, arg):
       
        """
	The command sets the max allowable velocity of the Az axis
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_TCU_AZMAXVEL(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # AZMAXPOS
    def SET_AZMAXPOS(self, arg):
       
        """
	The command sets the max allowable position of the Az axis in Telescope coordinate system
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_TCU_AZMAXPOS(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # AZMAXJERK
    def SET_AZMAXJERK(self, arg):
       
        """
	The command sets the max allowable jerk of the Az axis
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_TCU_AZMAXJERK(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # AZMINACC
    def SET_AZMINACC(self, arg):
       
        """
	The command sets the min allowable acceleration of the Az axis
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_TCU_AZMINACC(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # AZMINDEC
    def SET_AZMINDEC(self, arg):
       
        """
	The command sets the min allowable deceleration of the Az axis
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_TCU_AZMINDEC(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # AZMINVEL
    def SET_AZMINVEL(self, arg):
       
        """
	The command sets the min allowable velocity of the Az axis
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_TCU_AZMINVEL(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # AZMINPOS
    def SET_AZMINPOS(self, arg):
       
        """
	The command sets the min allowable position of the Az axis
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_TCU_AZMINPOS(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # AZMINJERK
    def SET_AZMINJERK(self, arg):
       
        """
	The command sets the min allowable jerk of the Az axis
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            result[telName] = self._devices[key].SET_TCU_AZMINJERK(arg)
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result


    # ----------------- List of Monitor Points ------------------
    def getMonitorList(self):
        """
        This method returns a list containing all monitor point
        names of this hardware device.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            monitorList = []
            monitorList.append("AZACTPOS --> xx.GET_AZACTPOS()")
            monitorList.append("AZENCPOS --> xx.GET_AZENCPOS()")
            monitorList.append("AZTELPOS --> xx.GET_AZTELPOS()")
            monitorList.append("AZACTVEL --> xx.GET_AZACTVEL()")
            monitorList.append("AZACTACC --> xx.GET_AZACTACC()")
            monitorList.append("AZTPOINT_CORR --> xx.GET_AZTPOINT_CORR()")
            monitorList.append("ELTPOINT_CORR --> xx.GET_ELTPOINT_CORR()")
            monitorList.append("REFRACTION_CORR --> xx.GET_REFRACTION_CORR()")
            result[telName] = monitorList
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result

    # ----------------- List of SET Points ------------------
    def getSetList(self):
        """
        This method returns a list containing all set point
        names of this hardware device.
        """
        result = {}
        for key, val in self._devices.items():
            telName = key.rsplit("/")[1]
            setList = []
            setList.append("AZMAXACC --> xx.SET_AZMAXACC(val)")
            setList.append("AZMAXDEC --> xx.SET_AZMAXDEC(val)")
            setList.append("AZMAXVEL --> xx.SET_AZMAXVEL(val)")
            setList.append("AZMAXPOS --> xx.SET_AZMAXPOS(val)")
            setList.append("AZMAXJERK --> xx.SET_AZMAXJERK(val)")
            setList.append("AZMINACC --> xx.SET_AZMINACC(val)")
            setList.append("AZMINDEC --> xx.SET_AZMINDEC(val)")
            setList.append("AZMINVEL --> xx.SET_AZMINVEL(val)")
            setList.append("AZMINPOS --> xx.SET_AZMINPOS(val)")
            setList.append("AZMINJERK --> xx.SET_AZMINJERK(val)")
            result[telName] = setList
            values = [*result.values()]
        if len(self._devices) == 1:
            return values[0]
        return result



